summaryrefslogtreecommitdiffstats
path: root/chrome/browser/in_process_webkit/webkit_thread.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/in_process_webkit/webkit_thread.cc')
-rw-r--r--chrome/browser/in_process_webkit/webkit_thread.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/in_process_webkit/webkit_thread.cc b/chrome/browser/in_process_webkit/webkit_thread.cc
index 486e703..8ff8174 100644
--- a/chrome/browser/in_process_webkit/webkit_thread.cc
+++ b/chrome/browser/in_process_webkit/webkit_thread.cc
@@ -14,11 +14,11 @@ WebKitThread::WebKitThread() {
// This happens on the UI thread after the IO thread has been shut down.
WebKitThread::~WebKitThread() {
// We can't just check CurrentlyOn(ChromeThread::UI) because in unit tests,
// MessageLoop::Current is sometimes NULL and other times valid and there's
- // no ChromeThread object. Can't check that CurrentlyOn is not IO since
- // some unit tests set that ChromeThread for other checks.
- DCHECK(!ChromeThread::CurrentlyOn(ChromeThread::WEBKIT));
+ // no BrowserThread object. Can't check that CurrentlyOn is not IO since
+ // some unit tests set that BrowserThread for other checks.
+ DCHECK(!BrowserThread::CurrentlyOn(BrowserThread::WEBKIT));
}
void WebKitThread::Initialize() {
@@ -35,7 +35,7 @@ void WebKitThread::Initialize() {
}
WebKitThread::InternalWebKitThread::InternalWebKitThread()
- : ChromeThread(ChromeThread::WEBKIT) {
+ : BrowserThread(BrowserThread::WEBKIT) {
}
WebKitThread::InternalWebKitThread::~InternalWebKitThread() {
@@ -14,11 +14,11 @@ WebKitThread::WebKitThread() {
// This happens on the UI thread after the IO thread has been shut down.
WebKitThread::~WebKitThread() {
- // We can't just check CurrentlyOn(ChromeThread::UI) because in unit tests,
+ // We can't just check CurrentlyOn(BrowserThread::UI) because in unit tests,
// MessageLoop::Current is sometimes NULL and other times valid and there's